# baserow-client

A Python client for [Baserow.io](https://baserow.io/) with simple ORM capabilities.

> __Note__: This package is currently under development. Some APIs may break without prior notice.

__Installation__

    $ pip install baserow-client
